@@ -41,8 +41,8 @@
 #endif
 
 /* OSS headers */
-#ifdef __FreeBSD__
-#include <machine/soundcard.h>
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
+#include <sys/soundcard.h>
 #else
 #include <linux/soundcard.h>
 #endif
@@ -219,7 +219,7 @@ static int generate_data(short* from,
                          dsp_t* dsp, unsigned char** to)
 {
   double speed_factor = (double) from_rate / dsp->rate; /* output to input */
-  int result_size = from_size * dsp->rate / from_rate; /* number of frames */
+  int result_size = (long long)from_size * dsp->rate / from_rate; /* number of frames */
   unsigned char* result;
   int i, j;
 
