@@ -153,11 +153,12 @@ static void set_speed_cb(metro_t *metro)
   *frequency = GTK_ADJUSTMENT(metro->speed_adjustment)->value / 60.0;
   if (debug)
     g_print ("set_speed_cb: rate=%f bpm\n", *frequency * 60.0);
+
+  gtk_label_set_text(GTK_LABEL(metro->tempo_name), get_tempo_name(*frequency * 60.0));
+
   comm_client_query(metro->inter_thread_comm,
                     MESSAGE_TYPE_SET_FREQUENCY,
 		    frequency);
-
-  gtk_label_set_text(GTK_LABEL(metro->tempo_name), get_tempo_name(*frequency * 60.0));
 }
 
 /*
@@ -1112,7 +1113,7 @@ static void set_meter_shortcut_destroy_notify(closure_data_t* closure_data,
   free(closure_data);
 }
 
-/* speed shortcuts */
+
 static void set_speed_shortcut_cb_plus(metro_t* metro) {
   gdouble speed =
     gtk_adjustment_get_value(GTK_ADJUSTMENT(metro->speed_adjustment));
@@ -1122,6 +1123,26 @@ static void set_speed_shortcut_cb_plus(metro_t* metro) {
 	                     speed + 1);
   }
 }
+static void set_speed_shortcut_cb_plusTwo(metro_t* metro) {
+  gdouble speed =
+    gtk_adjustment_get_value(GTK_ADJUSTMENT(metro->speed_adjustment));
+
+  if (speed + 2 <= GTK_ADJUSTMENT(metro->speed_adjustment)->upper) {
+    gtk_adjustment_set_value(GTK_ADJUSTMENT(metro->speed_adjustment),
+	                     speed + 2);
+  }
+}
+
+static void set_speed_shortcut_cb_plusTen(metro_t* metro) {
+  gdouble speed =
+    gtk_adjustment_get_value(GTK_ADJUSTMENT(metro->speed_adjustment));
+
+  if (speed + 10 <= GTK_ADJUSTMENT(metro->speed_adjustment)->upper) {
+    gtk_adjustment_set_value(GTK_ADJUSTMENT(metro->speed_adjustment),
+	                     speed + 10);
+  }
+}
+
 static void set_speed_shortcut_cb_minus(metro_t* metro) {
   gdouble speed =
     gtk_adjustment_get_value(GTK_ADJUSTMENT(metro->speed_adjustment));
@@ -1132,6 +1153,116 @@ static void set_speed_shortcut_cb_minus(metro_t* metro) {
   }
 }
 
+static void set_speed_shortcut_cb_minusTwo(metro_t* metro) {
+  gdouble speed =
+    gtk_adjustment_get_value(GTK_ADJUSTMENT(metro->speed_adjustment));
+
+  if (speed - 2 >= GTK_ADJUSTMENT(metro->speed_adjustment)->lower) {
+    gtk_adjustment_set_value(GTK_ADJUSTMENT(metro->speed_adjustment),
+	                     speed - 2);
+  }
+}
+
+static void set_speed_shortcut_cb_minusTen(metro_t* metro) {
+  gdouble speed =
+    gtk_adjustment_get_value(GTK_ADJUSTMENT(metro->speed_adjustment));
+
+  if (speed - 10 >= GTK_ADJUSTMENT(metro->speed_adjustment)->lower) {
+    gtk_adjustment_set_value(GTK_ADJUSTMENT(metro->speed_adjustment),
+	                     speed - 10);
+  }
+}
+
+static void set_speed_shortcut_cb_double(metro_t* metro) {
+  gdouble speed =
+    gtk_adjustment_get_value(GTK_ADJUSTMENT(metro->speed_adjustment));
+
+  if (speed * 2 <= GTK_ADJUSTMENT(metro->speed_adjustment)->upper) {
+    gtk_adjustment_set_value(GTK_ADJUSTMENT(metro->speed_adjustment),
+	                     speed *= 2);
+  }
+}
+
+
+static void set_speed_shortcut_cb_half(metro_t* metro) {
+  gdouble speed =
+    gtk_adjustment_get_value(GTK_ADJUSTMENT(metro->speed_adjustment));
+
+  if (speed / 2 >= GTK_ADJUSTMENT(metro->speed_adjustment)->lower) {
+    gtk_adjustment_set_value(GTK_ADJUSTMENT(metro->speed_adjustment),
+	                     speed /= 2);
+  }
+}
+
+
+
+static void set_volume_shortcut_cb_plusTwo(metro_t* metro) {
+  gdouble volume =
+    gtk_adjustment_get_value(GTK_ADJUSTMENT(metro->volume_adjustment));
+
+  if (volume + 2 <= 100) {
+    gtk_adjustment_set_value(GTK_ADJUSTMENT(metro->volume_adjustment),
+	                     volume + 2);
+  }
+}
+
+static void set_volume_shortcut_cb_minusTwo(metro_t* metro) {
+  gdouble volume =
+    gtk_adjustment_get_value(GTK_ADJUSTMENT(metro->volume_adjustment));
+
+  if (volume - 2 >= 0) {
+    gtk_adjustment_set_value(GTK_ADJUSTMENT(metro->volume_adjustment),
+	                     volume - 2);
+  }
+}
+
+static void set_volume_shortcut_cb_plusTen(metro_t* metro) {
+  gdouble volume =
+    gtk_adjustment_get_value(GTK_ADJUSTMENT(metro->volume_adjustment));
+
+  if (volume + 10 <= 100) {
+    gtk_adjustment_set_value(GTK_ADJUSTMENT(metro->volume_adjustment),
+	                     volume + 10);
+  }
+}
+
+static void set_volume_shortcut_cb_minusTen(metro_t* metro) {
+  gdouble volume =
+    gtk_adjustment_get_value(GTK_ADJUSTMENT(metro->volume_adjustment));
+
+  if (volume - 10 >= 0) {
+    gtk_adjustment_set_value(GTK_ADJUSTMENT(metro->volume_adjustment),
+	                     volume - 10);
+  }
+}
+
+
+static void set_volume_shortcut_cb_double(metro_t* metro) {
+  gdouble volume =
+    gtk_adjustment_get_value(GTK_ADJUSTMENT(metro->volume_adjustment));
+
+  if (volume * 2 <= 100) {
+    gtk_adjustment_set_value(GTK_ADJUSTMENT(metro->volume_adjustment),
+	                     volume *= 2);
+  }
+  else {
+    gtk_adjustment_set_value(GTK_ADJUSTMENT(metro->volume_adjustment),
+                               volume = 100);
+  }
+}
+
+static void set_volume_shortcut_cb_half(metro_t* metro) {
+  gdouble volume =
+    gtk_adjustment_get_value(GTK_ADJUSTMENT(metro->volume_adjustment));
+
+  if (volume / 2 >= 0) {
+    gtk_adjustment_set_value(GTK_ADJUSTMENT(metro->volume_adjustment),
+	                     volume /= 2);
+  }
+}
+
+
+
 /*
  * returns a new metro object
  */
@@ -1552,8 +1683,43 @@ metro_t* metro_new(void) {
   gtk_accel_group_connect(metro->accel_group, '+', GDK_CONTROL_MASK, 0,
       g_cclosure_new_swap(G_CALLBACK(set_speed_shortcut_cb_plus), metro, NULL));
   gtk_accel_group_connect(metro->accel_group, '-', GDK_CONTROL_MASK, 0,
-      g_cclosure_new_swap(G_CALLBACK(set_speed_shortcut_cb_minus),metro, NULL));
+      g_cclosure_new_swap(G_CALLBACK(set_speed_shortcut_cb_minus),metro, NULL)); 
   
+  gtk_accel_group_connect(metro->accel_group, 'x', GDK_MOD1_MASK, 0,
+      g_cclosure_new_swap(G_CALLBACK(set_speed_shortcut_cb_plusTwo), metro, NULL));
+  gtk_accel_group_connect(metro->accel_group, 'z', GDK_MOD1_MASK, 0,
+      g_cclosure_new_swap(G_CALLBACK(set_speed_shortcut_cb_minusTwo),metro, NULL));  
+  
+  gtk_accel_group_connect(metro->accel_group, 'd', GDK_CONTROL_MASK, 0,
+      g_cclosure_new_swap(G_CALLBACK(set_speed_shortcut_cb_double), metro, NULL));
+  gtk_accel_group_connect(metro->accel_group, 'h', GDK_CONTROL_MASK, 0,
+      g_cclosure_new_swap(G_CALLBACK(set_speed_shortcut_cb_half), metro, NULL)); 
+  
+  gtk_accel_group_connect(metro->accel_group, 'w', GDK_MOD1_MASK, 0,
+      g_cclosure_new_swap(G_CALLBACK(set_speed_shortcut_cb_double), metro, NULL));
+  gtk_accel_group_connect(metro->accel_group, 'q', GDK_MOD1_MASK, 0,
+      g_cclosure_new_swap(G_CALLBACK(set_speed_shortcut_cb_half), metro, NULL));  
+  
+  gtk_accel_group_connect(metro->accel_group, 's', GDK_MOD1_MASK, 0,
+      g_cclosure_new_swap(G_CALLBACK(set_speed_shortcut_cb_plusTen), metro, NULL));
+  gtk_accel_group_connect(metro->accel_group, 'a', GDK_MOD1_MASK, 0,
+      g_cclosure_new_swap(G_CALLBACK(set_speed_shortcut_cb_minusTen), metro, NULL)); 
+  
+  gtk_accel_group_connect(metro->accel_group, 'x', GDK_SHIFT_MASK, 0,
+      g_cclosure_new_swap(G_CALLBACK(set_volume_shortcut_cb_plusTwo), metro, NULL)); 
+  gtk_accel_group_connect(metro->accel_group, 'z', GDK_SHIFT_MASK, 0,
+      g_cclosure_new_swap(G_CALLBACK(set_volume_shortcut_cb_minusTwo),metro, NULL)); 
+ 
+  gtk_accel_group_connect(metro->accel_group, 's', GDK_SHIFT_MASK, 0,
+      g_cclosure_new_swap(G_CALLBACK(set_volume_shortcut_cb_plusTen), metro, NULL)); 
+  gtk_accel_group_connect(metro->accel_group, 'a', GDK_SHIFT_MASK, 0,
+      g_cclosure_new_swap(G_CALLBACK(set_volume_shortcut_cb_minusTen),metro, NULL)); 
+
+  gtk_accel_group_connect(metro->accel_group, 'w', GDK_SHIFT_MASK, 0,
+      g_cclosure_new_swap(G_CALLBACK(set_volume_shortcut_cb_double), metro, NULL)); 
+  gtk_accel_group_connect(metro->accel_group, 'q', GDK_SHIFT_MASK, 0,
+      g_cclosure_new_swap(G_CALLBACK(set_volume_shortcut_cb_half),metro, NULL)); 
+ 
   option_register(&metro->options->option_list,
                   "VisualTick",
 		  (option_new_t) new_visualtick,
